Learn R Programming

IVPP (version 1.1.2)

IVPP-package: IVPP: Invariance Partial Pruning Test

Description

An implementation of the Invariance Partial Pruning (IVPP) approach described in Du, X., Johnson, S. U., Epskamp, S. (2025) The Invariance Partial Pruning Approach to The Network Comparison in Longitudinal Data. IVPP is a two-step method that first test for global network structural difference with invariance test and then inspect specific edge difference with partial pruning. The package also allows you to compute centrality measures and use radar chart to plot. Analysis of bridge centralities by community pairs is also possible (e.g., the bridge strength from depression to anxiety, and from depression to panic disorder).

Arguments

Author

Maintainer: Xinkai Du xinkai.du.xd@gmail.com (ORCID) [copyright holder]

See Also