| gen_panelGVAR | R Documentation |
This function generates a (multi-group) panel GVAR model. Currently generating temporal and contemporaneous networks
gen_panelGVAR(
n_node = 6,
p_rewire_temp = 0.5,
p_rewire_cont = 0.5,
n_group = 1
)
n_node |
an integer denoting the number of nodes |
p_rewire_temp |
a numeric value between 0-1 denoting the extent of group difference in the temporal network |
p_rewire_cont |
a numeric value between 0-1 denoting the extent of group difference in the contemporaneous network |
n_group |
an integer denoting the number of groups |
beta can be transposed to obtain the temporal network;
PDC is the partial directed correlation matrix, which is a standardized version of temporal network;
kappa is the precision matrix denoting conditional (in)dependence,
which is a inverse of covariance matrix denoting the (dependence) among variables;
kappa can be further standardized to the contemporaneous networks (omega_zeta_within)
A list of beta, PDC, kappa and contemporaneous networks
Xinkai Du Maintainer: Xinkai Du xinkai.du.xd@gmail.com
library(IVPP)
# Generate the network
net_ls <- gen_panelGVAR(n_node = 6,
p_rewire_temp = 0.5,
p_rewire_cont = 0,
n_group = 2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.