beta can be transposed to obtain the temporal network;
PDC is the partial directed correlation matrix, which is a standardized version of temporal network;
kappa is the precision matrix denoting conditional (in)dependence,
which is a inverse of covariance matrix denoting the (dependence) among variables;
kappa can be further standardized to the contemporaneous networks (omega_zeta_within)