Learn R Programming

IVPP (version 1.1.0)

gen_panelGVAR: Generate a (multi-group) panelGVAR model

Description

This function generates a (multi-group) panel GVAR model. Currently generating temporal and contemporaneous networks

Usage

gen_panelGVAR(
  n_node = 6,
  p_rewire_temp = 0.5,
  p_rewire_cont = 0.5,
  n_group = 1
)

Value

A list of beta, PDC, kappa and contemporaneous networks

Arguments

n_node

an integer denoting the number of nodes

p_rewire_temp

a numeric value between 0-1 denoting the extent of group difference in the temporal network

p_rewire_cont

a numeric value between 0-1 denoting the extent of group difference in the contemporaneous network

n_group

an integer denoting the number of groups

Details

beta can be transposed to obtain the temporal network; PDC is the partial directed correlation matrix, which is a standardized version of temporal network; kappa is the precision matrix denoting conditional (in)dependence, which is a inverse of covariance matrix denoting the (dependence) among variables; kappa can be further standardized to the contemporaneous networks (omega_zeta_within)

Examples

Run this code
library(IVPP)
# Generate the network
net_ls <- gen_panelGVAR(n_node = 6,
                        p_rewire_temp = 0.5,
                        p_rewire_cont = 0,
                        n_group = 2)

Run the code above in your browser using DataLab