gen_tsGVAR: Generate time-series GVAR model for multiple (heterogeneous) individuals
Description
This function generates time-series GVAR model for multiple individuals that demonstrates difference or simularity.
Currently generating temporal and contemporaneous networks
A list of beta, PDC, kappa and contemporaneous networks
Arguments
n_node
an integer denoting the number of nodes
p_rewire_temp
a numeric value between 0-1 denoting the extent of individual difference in the temporal network
p_rewire_cont
a numeric value between 0-1 denoting the extent of individual difference in the contemporaneous network
n_persons
an integer denoting the number of individuals to generate tsGVAR for
Details
beta can be transposed to obtain the temporal network;
PDC is the partial directed correlation matrix, which is a standardized version of temporal network;
kappa is the precision matrix denoting conditional (in)dependence,
which is a inverse of covariance matrix denoting the (dependence) among variables;
kappa can be further standardized to the contemporaneous networks (omega_zeta_within)